@@ -5,10 +5,11 @@ PrimeLunch Utils
 from __future__ import annotations
 
 import datetime
+import html
 import logging
 import os
 import pathlib
-from typing import Any, Dict, List, Optional
+from typing import Any, Dict, Optional, Union
 
 import click
 import numpy as np
@@ -17,69 +18,31 @@ from numpy import datetime64
 from rich import print, table
 from rich.prompt import Confirm
 
-from lunchable import LunchMoney, TransactionUpdateObject
+from lunchable import TransactionUpdateObject
 from lunchable._config.logging_config import set_up_logging
-from lunchable.models import CategoriesObject, TransactionObject
+from lunchable.models import CategoriesObject, TransactionObject, UserObject
+from lunchable.plugins.base.pandas_app import LunchablePandasApp
 
 logger = logging.getLogger(__name__)
 
 
-class PrimeLunch:
+class PrimeLunch(LunchablePandasApp):
     """
     PrimeLunch: Amazon Notes Updater
     """
 
     def __init__(
         self,
-        file_path: str | os.PathLike,
+        file_path: Union[str, os.PathLike[str], pathlib.Path],
         time_window: int = 7,
         access_token: Optional[str] = None,
     ) -> None:
         """
         Initialize and set internal data
         """
+        super().__init__(cache_time=0, access_token=access_token)
         self.file_path = pathlib.Path(file_path)
         self.time_window = time_window
-        self.transaction_map: Dict[int, TransactionObject] = {}
-        self.cached = False
-        self.lunch = LunchMoney(access_token=access_token)
-        self.categories: dict[int, CategoriesObject] = {}
-
-    @staticmethod
-    def transactions_to_df(transactions: List[TransactionObject]) -> pd.DataFrame:
-        """
-        Convert Transactions Array to DataFrame
-
-        Parameters
-        ----------
-        transactions: List[TransactionObject]
-
-        Returns
-        -------
-        pd.DataFrame
-        """
-        return pd.DataFrame(
-            [item.dict() for item in transactions],
-            columns=TransactionObject.__fields__.keys(),
-        )
-
-    @staticmethod
-    def df_to_transactions(df: pd.DataFrame) -> List[TransactionObject]:
-        """
-        Convert DataFrame to Transaction Array
-
-        Parameters
-        ----------
-        df: pd.DataFrame
-
-        Returns
-        -------
-        List[TransactionObject]
-        """
-        array_df = df.copy()
-        array_df = array_df.fillna(np.nan).replace([np.nan], [None])
-        transaction_array = array_df.to_dict(orient="records")
-        return [TransactionObject(**item) for item in transaction_array]
 
     def amazon_to_df(self) -> pd.DataFrame:
         """
@@ -87,27 +50,21 @@ class PrimeLunch:
 
         This is pretty simple, except duplicate header rows need to be cleaned
 
-        Parameters
-        ----------
-        file_path: os.PathLike
-
         Returns
         -------
         pd.DataFrame
         """
-        dt64: np.dtype[datetime64] = np.dtype("datetime64[ns]")
-        string = pd.StringDtype(storage="python")
+        dt64: np.dtype[datetime64] = np.dtype("datetime64[ns]")  # type: ignore[assignment]
         expected_columns = {
-            "order id": string,
-            "items": string,
-            "to": string,
+            "order id": str,
+            "items": str,
+            "to": str,
             "date": dt64,
-            "total": float,
-            "shipping": float,
-            "shipping_refund": float,
-            "gift": float,
-            "refund": float,
-            "payments": string,
+            "total": np.float64,
+            "shipping": np.float64,
+            "gift": np.float64,
+            "refund": np.float64,
+            "payments": str,
         }
         amazon_df = pd.read_csv(
             self.file_path,
@@ -118,7 +75,9 @@ class PrimeLunch:
         ).all(axis=1)
         duplicate_header_rows = np.where(header_row_eval)[0]
         amazon_df.drop(duplicate_header_rows, axis=0, inplace=True)
-        amazon_df["total"] = amazon_df["total"].astype("string").str.replace(",", "")
+        amazon_df["total"] = (
+            amazon_df["total"].astype("string").str.replace(",", "").astype(np.float64)
+        )
         amazon_df = amazon_df.astype(dtype=expected_columns, copy=True, errors="raise")
         logger.info("Amazon Data File loaded: %s", self.file_path)
         return amazon_df
@@ -170,6 +129,59 @@ class PrimeLunch:
         deduped = deduped[deduped["duplicated"] == False]  # noqa:E712
         return deduped
 
+    @classmethod
+    def _extract_total_from_payments(cls, df: pd.DataFrame) -> pd.DataFrame:
+        """
+        Extract the Credit Card Payments from the payments column
+
+        There is quite a bit of data manipulation going on here. We
+        need to extract meaningful credit card transaction info from strings like this:
+
+        Visa ending in 9470: September 11, 2022: $29.57; \
+        Visa ending in 9470: September 11, 2022: $2.22;
+        """
+        extracted = df.copy()
+        extracted["new_total"] = extracted["payments"].str.rstrip(";").str.split(";")
+        exploded_totals = extracted.explode("new_total", ignore_index=True)
+        exploded_totals = exploded_totals[
+            exploded_totals["new_total"].str.strip() != ""
+        ]
+        currency_matcher = r"(?:[\£\$\€]{1}[,\d]+.?\d*)"
+        exploded_totals["parsed_total"] = exploded_totals["new_total"].str.findall(
+            currency_matcher
+        )
+        exploded_totals = exploded_totals.explode("parsed_total", ignore_index=True)
+        exploded_totals["parsed_total"] = exploded_totals["parsed_total"].str.replace(
+            "[^0-9.]", "", regex=True
+        )
+        exploded_totals["parsed_total"] = exploded_totals["parsed_total"].astype(
+            np.float64
+        )
+        exploded_totals = exploded_totals[~exploded_totals["parsed_total"].isnull()]
+        exploded_totals["total"] = np.where(
+            ~exploded_totals["parsed_total"].isnull(),
+            exploded_totals["parsed_total"],
+            exploded_totals["total"],
+        )
+        return exploded_totals
+
+    @classmethod
+    def _extract_extra_from_orders(cls, df: pd.DataFrame) -> pd.DataFrame:
+        """
+        Extract the Credit Card Refunds and Whole Foods Orders
+        """
+        refunds = df.copy()
+        refunded_data = refunds[refunds["refund"] > 0].copy()
+        refunded_data["total"] = -refunded_data["refund"]
+        refunded_data["items"] = "REFUND: " + refunded_data["items"]
+        complete_amazon_data = pd.concat([refunds, refunded_data], ignore_index=True)
+        complete_amazon_data["items"] = np.where(
+            complete_amazon_data["to"].str.startswith("Whole Foods"),
+            "Whole Foods Groceries",
+            complete_amazon_data["items"],
+        )
+        return complete_amazon_data
+
     @classmethod
     def merge_transactions(
         cls, amazon: pd.DataFrame, transactions: pd.DataFrame, time_range: int = 7
@@ -189,16 +201,9 @@ class PrimeLunch:
         -------
         pd.DataFrame
         """
-        refunded_data = amazon[amazon["refund"] > 0].copy()
-        refunded_data["total"] = -refunded_data["refund"]
-        refunded_data["items"] = "REFUND: " + refunded_data["items"]
-        complete_amazon_data = pd.concat([amazon, refunded_data], ignore_index=True)
+        exploded_totals = cls._extract_total_from_payments(df=amazon)
+        complete_amazon_data = cls._extract_extra_from_orders(df=exploded_totals)
         merged_data = transactions.copy()
-        complete_amazon_data["items"] = np.where(
-            complete_amazon_data["to"].str.startswith("Whole Foods"),
-            "Whole Foods Groceries",
-            complete_amazon_data["items"],
-        )
         merged_data = merged_data.merge(
             complete_amazon_data,
             how="inner",
@@ -240,15 +245,17 @@ class PrimeLunch:
             start_date,
             end_cache_date,
         )
-        transactions = self.lunch.get_transactions(
-            start_date=start_date, end_date=end_cache_date
+        self.get_latest_cache(include=[CategoriesObject, UserObject])
+        self.refresh_transactions(start_date=start_date, end_date=end_cache_date)
+        logger.info(
+            'Scanning LunchMoney Budget: "%s"',
+            html.unescape(self.lunch_data.user.budget_name),
         )
-        transaction_map = {item.id: item for item in transactions}
-        self.categories = {item.id: item for item in self.lunch.get_categories()}
-        self.transaction_map = transaction_map
-        self.cached = True
-        logger.info("%s transactions returned from LunchMoney", len(transactions))
-        return transaction_map
+        logger.info(
+            "%s transactions returned from LunchMoney",
+            len(self.lunch_data.transactions),
+        )
+        return self.lunch_data.transactions
 
     def print_transaction(
         self, transaction: TransactionObject, former_transaction: TransactionObject
@@ -266,7 +273,8 @@ class PrimeLunch:
         )
         if former_transaction.category_id is not None:
             transaction_table.add_row(
-                "📊 Category", self.categories[former_transaction.category_id].name
+                "📊 Category",
+                self.lunch_data.categories[former_transaction.category_id].name,
             )
         if (
             former_transaction.original_name is not None
@@ -299,7 +307,7 @@ class PrimeLunch:
         -------
         Optional[Dict[str, Any]]
         """
-        former_transaction = self.transaction_map[transaction.id]
+        former_transaction = self.lunch_data.transactions[transaction.id]
         response = None
         stripped_notes = transaction.notes.strip()  # type: ignore[union-attr]
         acceptable_length = min(349, len(stripped_notes))
@@ -322,7 +330,7 @@ class PrimeLunch:
                     print(f"\t✅ Transaction #{transaction.id} updated")
         return response
 
-    def process_transactions(self, confirm: bool = True):
+    def process_transactions(self, confirm: bool = True) -> None:
         """
         Run the End-to-End Process
         """
@@ -340,8 +348,8 @@ class PrimeLunch:
             max_date,
         )
         self.cache_transactions(start_date=min_date, end_date=max_date)
-        transaction_df = self.transactions_to_df(
-            transactions=list(self.transaction_map.values())
+        transaction_df = self.models_to_df(
+            models=self.lunch_data.transactions.values(),
         )
         amazon_transaction_df = self.filter_amazon_transactions(df=transaction_df)
         merged_data = self.merge_transactions(
@@ -349,7 +357,9 @@ class PrimeLunch:
             amazon=amazon_df,
             time_range=self.time_window,
         )
-        updated_transactions = self.df_to_transactions(df=merged_data)
+        updated_transactions = self.df_to_models(
+            df=merged_data, model_type=TransactionObject
+        )
         responses = []
         for item in updated_transactions:
             resp = self.update_transaction(transaction=item, confirm=confirm)
@@ -414,7 +424,9 @@ class PrimeLunch:
     help="LunchMoney Access Token - defaults to the LUNCHMONEY_ACCESS_TOKEN environment variable",
     envvar="LUNCHMONEY_ACCESS_TOKEN",
 )
-def run_primelunch(csv_file: str, window: int, update_all: bool, access_token: str):
+def run_primelunch(
+    csv_file: str, window: int, update_all: bool, access_token: str
+) -> None:
     """
     Run the PrimeLunch Update Process
     """
